@@ -2,7 +2,7 @@
 if [ $# -ne 1 ]; then
     cat <<EOF
    useage: ./AutoCreateTab.sh  dir
-         dir:   ouptu. directory such as /tmp/$USER/Media
+         dir:   ouput directory such as /tmp/$USER/Media
 EOF
 exit
 fi
