@@ -165,6 +165,6 @@
 
       real*8 ans
       call epBrgeneTX(v, vmax, ans)
-      epBrgeneSolv =1.0d0- ans/upsi
-!      epBrgeneSolv = log(ans/upsi)  ! ifans 0 ? seems ok
+!     epBrgeneSolv =1.0d0- ans/upsi
+      epBrgeneSolv = log(ans/upsi)  ! ifans 0 ? seems ok
       end function epBrgeneSolv
