@@ -1,3 +1,4 @@
+!   #define DEBUGS
       subroutine epCreBrSTblS(mediain, cnst)
       implicit none
 #include "Zmedia.h"
@@ -331,7 +332,7 @@
       common/upsic/upsi, vmax
       real*8 vmax, upsi
 
-      data eps/1.d-5/
+      data eps/1.d-8/
 
 
       de1 = 10.d0**cnst%BrdES
@@ -379,10 +380,22 @@
      *              ' vmin=', vmin, ' tcb=', tcb
             endif
             bla(iu,i)= log(v/vmin)/(1.-u)
+#if defined (DEBUGS)            
+!!!!!!
+            write(0,'(a, i3,1p, 4g14.6)')
+     *           'ss1 ', iu, Ek, u, v, bla(iu, i)
+!!!!!!!            
+#endif
             u=u + cnst%BrdUSA
             vr = v
          enddo
          bla(sizeu, i)=tcb/vmin/epBrgene(media, force, Ee, vmin)
+#if defined (DEBUGS)                     
+!!!!!!!!
+         write(0,'(a, i3,1p, 4g14.6)')
+     *           'ss1 ', sizeu, Ek, u, vmin, bla(sizeu, i)
+!!!!!!!
+#endif         
          Ek =Ek* de1
       enddo
       call epwt2dTbl(
@@ -409,6 +422,7 @@
 
       real*8  epBrgene
 
+      real(8),parameter:: dv=10.0d0**0.05d0
       character*160 msg
       integer i, iu, j
 
@@ -416,7 +430,7 @@
       common/upsic/upsi, vmax
       real*8 vmax, upsi
 
-      data eps/1.d-5/
+      data eps/1.d-8/
       de1 = 10.d0**cnst%BrdES2
 
       Ee = cnst%BrEeminS2    
@@ -450,25 +464,40 @@
             upsi=u*tcb
 !             v here obtained is Eg/Ee
             call kbchop(epBrgeneSolv, vl, vr, eps, v, j)
-            
             if(j .le. 0) then
                
                write(0, *) ' cond, Ek, u=', j, Ek, u
-               do vx = vmin, vmax, (vmax-vmin)/100.d0
-!                  call eptotcbS(vx, vmax, tcbx)
-                  call epBrgeneTX(vx, vmax, tcbx)
-                  write(0, *) vx, tcbx
-               enddo
                write(0,*) 'u upsi, vl, vr', u,
      *              upsi, vl, vr,
      *              ' vmin=', vmin, ' tcb=', tcb
+                              
+               vx = vmin
+!     do vx = vmin, vmax, (vmax-vmin)/100.d0
+               do while ( vx < vmax)
+!                  call eptotcbS(vx, vmax, tcbx)
+                  call epBrgeneTX(vx, vmax, tcbx)
+                  write(0, *) vx, tcbx, 1.d0 - tcbx/upsi
+                  vx = vx * dv
+               enddo
             endif
             bla(iu,i)= log(v/vmin)/(1.-u)
+#if defined (DEBUGS)                                 
+!!!!! 
+            write(0,'(a, i3, 1p, 4g13.4)') 'ss2 ', iu, Ek, u, v,
+     *      bla(iu,i)
+!!!!!!!!!!
+#endif            
             u=u + cnst%BrdUSA2
-            vr = v
+            vr = min(v*dv*dv*dv, vmax)
          enddo
 !         bla(sizeu, i)=tcb/vmin/epBrSfs(media, Eeme, vmin) ! <= v9.136
          bla(sizeu, i)=tcb/vmin/epBrgene(media, force, Ee, vmin)
+#if defined (DEBUGS)                                          
+!!!!!!!!!         
+         write(0,'(a, i3, 1p, 4g13.4)') 'ss2 ', sizeu, Ek, u, vmin,
+     *        bla(sizeu,i)
+!!!!!!!!
+#endif         
                            ! generic  function must be used otherwise, when LPM
                            ! comes in this region, results in wrong.
                            ! (eBrSfs dose not include LPM)
@@ -534,9 +563,9 @@
             u=us**4
             upsi=u*tcb
             if(iu .le .6) then
-               eps = 1.d-7
+               eps = 1.d-8
             else
-               eps = 1.d-5
+               eps = 1.d-8
             endif
             
             call kbchop(epBrgeneSolv, vl, vr, eps, v, j)
@@ -544,10 +573,22 @@
                write(0,'('' Ek,u='',2g12.3)') Ek, u
             endif
             blb(iu,ie) = log(vmax/v)/u
+#if defined (DEBUGS)                                                      
+!!!!! 
+            write(0,'(a, i3, 1p, 5g13.4)') 'ss3 ', iu, Ek, us, v,
+     *             blb(iu,ie), u
+!!!!!!!!!!
+#endif            
             us=us + cnst%BrdUSB
             vr = v
          enddo
          blb(1, ie) = tcb/vmax/epBrgene(media, force, Ee, vmax)
+#if defined (DEBUGS)                                                      
+!!!!! 
+         write(0,'(a, i3, 1p, 5g13.4)') 'ss3 ', 1, Ek, cnst%BrUminSB,
+     *     vmax,  blb(1, ie), cnst%BrUminSB**4
+!!!!!!!!!!
+#endif                     
          Ek= Ek*de1
        enddo
        
@@ -605,20 +646,32 @@
             u=us**4
             upsi=u*tcb
             if(iu .le .6) then
-               eps = 1.d-7
+               eps = 1.d-8
             else
-               eps = 1.d-5
+               eps = 1.d-8
             endif
-            
+
             call kbchop(epBrgeneSolv, vl, vr, eps, v, j)
             if(j .le. 0) then
                write(0,'('' Ek,u='',2g12.3)') Ek, u
             endif
             blb(iu,ie) = log(vmax/v)/u
+#if defined (DEBUGS)
+!!!!!
+            write(0,'(a, i3, 1p, 5g13.4)') 'ss4 ', iu, Ek, us, v,
+     *           blb(iu,ie), u
+!!!!!!!!!!            
+#endif
             us=us + cnst%BrdUSB2
             vr = v
          enddo
          blb(1, ie) = tcb/vmax/epBrgene(media, force, Ee, vmax)
+#if defined (DEBUGS)                                                           
+!!!!! 
+         write(0,'(a, i3, 1p, 5g13.4)') 'ss4 ', 1, Ek, cnst%BrUminSB2,
+     *         vmax,    blb(1, ie), cnst%BrUminSB2**4
+!!!!!!!!!!
+#endif
          Ek= Ek*de1
        enddo
        
