@@ -1,5 +1,5 @@
 #!/bin/bash
-work=Work
+work=/tmp/$USER/Work
 if [ $#  -ne 3 ]; then
 cat <<EOF
     Usage: ./testXS.sh  media  norm  XCOM
@@ -11,6 +11,8 @@ EOF
     exit
 fi
 
+mkdir -p $work
+
 media=$1;  norm=$2
 # from 10keV to 100GeV log step 0.1
 #E1=10.e-6
@@ -28,7 +30,7 @@ make -f DrawComptonXS.mk
 #for f in $(seq 1 $nbin); do
 #  echo ${f}-th energy=$Ek 
 
-  echo  $media  $XCOM  | ./XS.out > $work/compton.xs
+  echo  $XCOM $media  | ./XS.out > $work/compton.xs
 
   echo "set xlab \"Eg(MeV)\"" > $work/gnuplot.com
   echo "set log xy"  >> $work/gnuplot.com
@@ -47,8 +49,8 @@ make -f DrawComptonXS.mk
   echo "set ylab \"$ylab\"" >> $work/gnuplot.com
 
   let u=$norm+1
-  echo "plot  \"Work/compton.xs\" u 1:$u  w l lw 3 lt 3" >> $work/gnuplot.com
-  cat XS.gp >> $work/gnuplot.com
+  echo "plot  \"$work/compton.xs\" u 1:$u  w l lw 3 lt 3" >> $work/gnuplot.com
+  cat XS.gp | awk '{gsub(/WWW/,this);print}' this=$work  >> $work/gnuplot.com
 
 
   echo  set output  \"$work/compton{f}.png\" >>$work/gnuplot.com
