@@ -13,10 +13,10 @@
 #include "Zmove.h"
 #include "Zep3Vec.h"
 
-c          common variables used in tracking ptcls.
-       record /epTrack/ cTrack    !  current track
-       record /epTrack/ Incident  ! to keep 1st stacked track
-       record /epmove/ Move         ! to contain info for moving a
+!          common variables used in tracking ptcls.
+       type(epTrack)::  cTrack    !  current track
+       type(epTrack)::  Incident  ! to keep 1st stacked track
+       type(epmove)::  Move         ! to contain info for moving a
                                   ! track  
                    
 	real*8  Ethin         ! Thin sampling threshold.
@@ -25,10 +25,12 @@ c          common variables used in tracking ptcls.
         
 
         integer Cn        !  current particle cn
-        record /epmedia/Media(Maxmedia)
+        integer FirstCn   !  first collision (decay etc) occurred
+                   ! in this component #
+       type(epmedia):: Media(Maxmedia)
         integer MediaNo   !  current particle media no = Cn2media(cn)
         integer NoOfMedia !  No of media 
-c       >>>>>>>>>>>>>>>>>>>>>>light
+!       >>>>>>>>>>>>>>>>>>>>>>light
         integer CrossMode ! 0-->crossing self boundary, 1-->crossing matreshka
                           ! 2-->crossing container which partially contains current comp.
         integer cLcompNo  !  current Light componet no
@@ -41,18 +43,18 @@ c       >>>>>>>>>>>>>>>>>>>>>>light
                   	  !  e.g, comInfo(cPtyNo)%refracIndex 
                           !  These are set whenever a ptlc move to a
                           !  new component
-c       <<<<<<<<<<<<<<<<<<<<
+!       <<<<<<<<<<<<<<<<<<<<
         logical Firsti, FirstC ! to set  first  collision/interaction 
         logical ImperativeEmin ! if becomes T, residual range is not
                             ! considered when KE< Emin.
-        record /epmedia/FirstMedia  ! first collision media
+       type(epmedia):: FirstMedia  ! first collision media
         character*8  Proc1 ! to keep first interaction type
-        record /epPos/ FirstInt !  to keep first int. pos.
-        					       
-        record /ep3Vec/ Bfield   !  Bfield.x, y, z  the B in  Tesla
+       type(epPos)::  FirstInt !  to keep first int. pos.
+       type(epTrack):: FirstIntTrack ! to keep first int track ptcl
+       type(ep3Vec)::  Bfield   !  Bfield.x, y, z  the B in  Tesla
                                 !    in local coordinate 
         real*8   pathInB        !  total path length in B for a particle 
-        record /ep3Vec/ Efield   !  Efiled.x, y, z  the E in V/m
+       type(ep3Vec)::  Efield   !  Efiled.x, y, z  the E in V/m
                                 !   local coordinate.
         real*8 SumDe       !  sum  of all energy deposit
 
@@ -67,13 +69,13 @@ c       <<<<<<<<<<<<<<<<<<<<
                            ! something wrong may be happing so that we
 			     ! stop the executon ( in epbndry ).	       
         integer Making1ry  ! =1 during preparing 1ry for each event 
-c
+!
        common /ZepTrackv/ Media, FirstMedia,
      *  Incident, cTrack, Move, 
      *  Bfield, Efield,
-     *  FirstInt, MaxPath, Upsilon, Xai,  pathInB,
-     *  Beta, Tcoefx, Tminx,  SumDe, Cn, MediaNo,
-     *  NoOfMedia, Ethin, Total1ryE,
+     *  FirstInt, FirstIntTrack, MaxPath, Upsilon, Xai,  pathInB,
+     *  Beta, Tcoefx, Tminx,  SumDe, Cn,  FirstCn,
+     *  MediaNo,  NoOfMedia, Ethin, Total1ryE,
      *  Firsti, FirstC, Bndryerr, cLcompNo, cPtyNo,
      *  CrossMode, ImperativeEmin, Making1ry
 
