@@ -18,8 +18,11 @@
       cnst%CompScrE =  !  30.0*( 0.05*0.99/0.01/media.Zeff**0.333)
 !     *              150.0/media.Zeff**0.333
      *              150.0/media%Z**0.333
-!
-      cnst%BremEgmin =  1.d-5 ! min Eg/Ee at  Ee > 100 MeV
+!     When sampling is tried, andi if a table already made has a
+!     different min, the next value  will be replaced by such a value.
+!      
+      cnst%BremEgmin =  1.d-5   ! min Eg/Ee at  Ee > 100 MeV
+
 !
 !       For Seltzer data
 !   
@@ -63,7 +66,8 @@
 ! ----------------- 100MeV to 10 GeV Seltzer upper region
       cnst%BrEemaxS2  = 10.  ! max of the upper Seltzer data 
                                 !     region  (10GeV)
-      cnst%BrEgminS2 = 1.0d-5  ! Eg/Ee min for upper Seltzer region
+!!!      cnst%BrEgminS2 = 1.0d-5   ! Eg/Ee min for upper Seltzer region
+      cnst%BrEgminS2 =  cnst%BremEgmin  ! min Eg/Ee at  Ee > 100 MeV5.0d-6   ! Eg/Ee min for upper Seltzer region
                                ! *** ratio ***.
                                ! Eg=100keV to 1keV
       cnst%BrEeminS2 =  cnst%BrEemaxS ! 100. MeV
