@@ -132,25 +132,25 @@
 !     *     Incident.wl, Incident.cn, Incident.user
 !c/////////
 !         write(OutPrimaryFileNo,*)  FirstInt
-c/////////////
+!/////////////
 !         write(0,*) ' FirstInt=',   FirstInt
-c/////////
+!/////////
 !         write(OutPrimaryFileNo,*)  FirstMedia.name, 
 !     *    FirstMedia.colZ, FirstMedia.colA
-c/////////////
+!/////////////
 !         write(0,*) ' FirstMedia=',   FirstMedia.name,
 !     *    FirstMedia.colZ, FirstMedia.colA
-c/////////
+!/////////
          write(OutPrimaryFileNo,*)  Proc1
-c/////////////
+!/////////////
 !         write(0,*) ' Proc1=',    Proc1
-c/////////
+!/////////
       else
          write(OutPrimaryFileNo)  cevent
          write(OutPrimaryFileNo)  Incident
          write(OutPrimaryFileNo)  FirstInt
-         write(OutPrimaryFileNo)  FirstMedia.name, 
-     *         FirstMedia.colZ, FirstMedia.colA
+         write(OutPrimaryFileNo)  FirstMedia%name, 
+     *         FirstMedia%colZ, FirstMedia%colA
          write(OutPrimaryFileNo)  Proc1
       endif
       end
@@ -173,7 +173,7 @@ c/////////
 !     *     Incident.pos,
 !     *     Incident.t, Incident.w, Incident.wgt, Incident.pol,
 !     *     Incident.wl, Incident.cn, Incident.user
-c///////////
+!///////////
 !         write(0,*)
 !     *     Incident.p.code, 
 !     *     Incident.p.subcode, Incident.p.charge,
@@ -181,40 +181,40 @@ c///////////
 !     *     Incident.pos,
 !     *     Incident.t, Incident.w, Incident.wgt, Incident.pol,
 !     *     Incident.wl, Incident.cn, Incident.user
-c////////////
+!////////////
 !
          read(Ioprim,*)  FirstInt
-         read(Ioprim,*)  FirstMedia.name,
-     *         FirstMedia.colZ, FirstMedia.colA
-c///////////
+         read(Ioprim,*)  FirstMedia%name,
+     *         FirstMedia%colZ, FirstMedia%colA
+!///////////
 !         write(0,'(a,2f8.0)')  FirstMedia.name,
 !     *         FirstMedia.colZ, FirstMedia.colA
-c////////////
+!////////////
 
          read(Ioprim,*)  Proc1
-c///////////
+!///////////
 !         write(0,*)  Proc1
-c////////////
+!////////////
 
       else
          read(Ioprim, end=100)  cevent
          read(Ioprim)  Incident
-c///////////
-c         write(0,*)
-c     *     Incident.p.code, 
-c     *     Incident.p.subcode, Incident.p.charge,
-c     *     Incident.p.fm.p, Incident.p.mass,
-c     *     Incident.pos,
-c     *     Incident.t, Incident.w, Incident.wgt, Incident.pol,
-c     *     Incident.wl, Incident.cn, Incident.user
-cc////////////
+!///////////
+!         write(0,*)
+!     *     Incident.p.code, 
+!     *     Incident.p.subcode, Incident.p.charge,
+!     *     Incident.p.fm.p, Incident.p.mass,
+!     *     Incident.pos,
+!     *     Incident.t, Incident.w, Incident.wgt, Incident.pol,
+!     *     Incident.wl, Incident.cn, Incident.user
+!c////////////
          read(Ioprim)  FirstInt
-         read(Ioprim)  FirstMedia.name,
-     *         FirstMedia.colZ, FirstMedia.colA
-c///////////
-c         write(0,*) FirstMedia.name,
-c     *         FirstMedia.colZ, FirstMedia.colA
-c////////////
+         read(Ioprim)  FirstMedia%name,
+     *         FirstMedia%colZ, FirstMedia%colA
+!///////////
+!         write(0,*) FirstMedia.name,
+!     *         FirstMedia.colZ, FirstMedia.colA
+!////////////
          read(Ioprim)  Proc1
       endif
       Nevrun = cevent
